<?php
namespace App\JsonRpc;

use App\Model\Article;
use App\Model\ArticleData;
use App\Model\Category;
use App\Model\WebsiteCategory;
use App\Model\ArticleSurvey;
use App\Model\jobHunting;
use App\Model\JobEnum;
use App\Model\JobIndustry;
use App\Model\JobPosition;
use App\Model\JobRecruiting;
use App\Model\Good;
use App\Model\JobNature;
use App\Model\Website;
use Hyperf\DbConnection\Db;
use Hyperf\RpcServer\Annotation\RpcService;
use App\Tools\Result;
use Ramsey\Uuid\Uuid;
use Hyperf\Utils\Random;
use Fukuball\Jieba\Jieba;
use Fukuball\Jieba\Finalseg;

#[RpcService(name: "NewsService", protocol: "jsonrpc-http", server: "jsonrpc-http")]
class NewsService implements NewsServiceInterface
{

    /**
     * 获取导航池列表
     * @param array $data
     * @return array
     */
    public function getCategoryList(array $data): array
    {
        $rep = Category::select("category.*")->orderBy('category.updated_at', "desc")->get();
        if (empty($rep)) {
            return Result::error("没有导航池数据");
        }
        return Result::success($rep);
    }
    public function myCategoryList(array $data): array
    {
        $sszq = $data['sszq'] ?? '';
        unset($data['sszq']);
        //1,2,3 根据这些webid，。从website_category表中取出对应的分类id，然后从category表中取出分类信息
        $catorytids = WebsiteCategory::whereIn('website_id', explode(',', $sszq))->get()->pluck('category_id')->toArray();
        $where[] = [
            'pid', '=', $data['pid'],
        ];
        if (isset($data['name'])) {
            array_push($where, ['category.name', 'like', '%' . $data['name'] . '%']);
        }
        var_dump($where);
        //根据分类id，从category表中取出分类信息
        $result = Category::where($where)
            ->whereIn('category.id', $catorytids)
            ->select('category.*', 'category.id as category_id')->get();
        if (empty($result)) {
            return Result::error("没有栏目数据");
        }
        return Result::success($result);
    }
    /**
     * @param array $data
     * @return array
     */
    public function categoryList(array $data): array
    {
        $where[] = [
            'pid', '=', $data['pid'],
        ];
        if (isset($data['name'])) {
            array_push($where, ['category.name', 'like', '%' . $data['name'] . '%']);
        }
        var_dump($where);
        $result = Category::where($where)->select('category.*', 'category.id as category_id')->get();
        if (empty($result)) {
            return Result::error("没有栏目数据");
        }
        return Result::success($result);
    }
    /**
     * @param array $data
     * @return array
     */
    public function addCategory(array $data): array
    {
        if (isset($data['id'])) {
            unset($data['id']);
        }
        $id = Category::insertGetId($data);
        if (empty($id)) {
            return Result::error("添加失败");
        }
        return Result::success(['id' => $id]);
    }

    /**
     * @param array $data
     * @return array
     */
    public function delCategory(array $data): array
    {
        $categoryList = Category::where(['pid' => $data['id']])->get();
        var_dump("分类列表：", $data, $categoryList);
        if ($categoryList->toArray()) {
            return Result::error("分类下面有子分类不能删除");
        }
        $articleList = Article::where(['catid' => $data['id']])->get();
        var_dump("文章列表：", $articleList);
        if ($articleList->toArray()) {
            return Result::error("分类下面有资讯不能删除");
        }
        $result = Category::where($data)->delete();
        if (!$result) {
            return Result::error("删除失败");
        }
        return Result::success($result);
    }

    /**
     * @param array $data
     * @return array
     */
    public function updateCategory(array $data): array
    {
        $where = [
            'id' => $data['id'],
        ];
        $result = Category::where($where)->update($data);
        if ($result) {
            return Result::success($result);
        } else {
            return Result::error("更新失败");
        }
    }

    /**
     * 获取导航池信息
     * @param array $data
     * @return array
     */
    public function getCategoryInfo(array $data): array
    {
        $where = [
            'id' => $data['id'],
        ];
        $result = Category::where($where)->first();
        if ($result) {
            return Result::success($result);
        } else {
            return Result::error("更新失败");
        }
    }
    /**
     * @param array $data
     * @return array
     */
    public function getArticleList(array $data): array
    {
        //判断是否是管理员'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
        $type_id = $data['type_id'];
        unset($data['type_id']);
        $user_id = $data['user_id'];
        unset($data['user_id']);

        $where = [];
        $status1 = [];

        if (isset($data['title']) && $data['title']) {
            array_push($where, ['article.title', 'like', '%' . $data['title'] . '%']);
        }
        if (isset($data['category_name']) && $data['category_name']) {
            array_push($where, ['category.name', 'like', '%' . $data['category_name'] . '%']);
        }
        if (isset($data['author']) && $data['author']) {
            array_push($where, ['article.author', '=', $data['author']]);
        }
        if (isset($data['islink']) && $data['islink'] !== "") {
            array_push($where, ['article.islink', '=', $data['islink']]);
        }
        if (isset($data['status']) && $data['status'] !== "") {
            array_push($where, ['article.status', '=', $data['status']]);
        }
        if (isset($data['status1'])) {
            $status1 = json_decode(($data['status1']));
        }
        //不是管理员展示个人数据；
        if ($type_id != 10000) {
            $where[] = ['article.admin_user_id', '=', $user_id];
        }

        $rep = Article::where($where)
            ->whereNotIn('article.status', [404])
            ->when($status1, function ($query) use ($status1) {
                if (isset($status1) && $status1) {
                    $query->whereIn('article.status', $status1);
                }
            })
            ->leftJoin('category', 'article.catid', 'category.id')
            ->select("article.*", "category.name as category_name")
            ->orderBy("article.updated_at", "desc")
            ->limit($data['pageSize'])
            ->offset(($data['page'] - 1) * $data['pageSize'])->get();
        $count = Article::where($where)->whereNotIn('article.status', [404])
            ->when($status1, function ($query) use ($status1) {
                if (isset($status1) && $status1) {
                    $query->whereIn('article.status', $status1);
                }
            })
            ->leftJoin('category', 'article.catid', 'category.id')->count();
        $data = [
            'rows' => $rep->toArray(),
            'count' => $count,
        ];
        if (empty($rep)) {
            return Result::error("没有信息数据");
        }
        return Result::success($data);
    }

    /**
     * @param array $data
     * @return array
     */
    public function addArticle(array $data): array
    {
        var_dump($data, '----------12-----------1');
        unset($data['user_type']);
        unset($data['nav_add_pool_id']);
        // $data['cat_arr_id'] = is_string($data['cat_arr_id']) ? json_encode($data['cat_arr_id']) : '';
        Db::beginTransaction();
        try {
            //处理投票
            $is_survey = isset($data['is_survey']) ? $data['is_survey'] : 0;
            $survey_name = isset($data['survey_name']) ? $data['survey_name'] : '';
            $suvey_array = isset($data['suvey_array']) ? $data['suvey_array'] : '';
            $website_id = isset($data['website_id']) ? $data['website_id'] : 2;
            unset($data['is_survey']);
            unset($data['survey_name']);
            unset($data['suvey_array']);
            // unset($data['website_id']);
            // unset($data['web_site_id']);
            // $data['web_site_id'] = is_array($data['web_site_id']) ? json_encode($data['web_site_id']) : ($data['web_site_id']);
            if ($data['hits'] == '') {
                $data['hits'] = 0;
            }
            if ($data['is_original'] == '') {
                $data['is_original'] = 0;
            }
            if ($data['status'] == '') {
                $data['status'] = 0;
            }
            $articleData = $data;
            unset($articleData['content']);
            //自动处理缩略图、关键字、描述
            if ($articleData['imgurl'] == '') {
                //如果没有图，设置level=0
                $levelArr = json_decode($articleData['level'], true);
                var_dump($levelArr, '----------levelArr-----------1');
                //content中提取图片第一个图，正则提取
                $reg = '/<img.*?src=[\"|\']?(.*?)[\"|\']?\s.*?>/i';
                preg_match_all($reg, $data['content'], $matches);
                if (isset($matches[1][0])) {
                    $articleData['imgurl'] = $matches[1][0];
                    //如果有图，设置level=3
                    if (!in_array(3, $levelArr)) {$levelArr[] = 3;}
                    $articleData['level'] = json_encode($levelArr);
                } else {
                    if (!in_array(0, $levelArr)) {
                        $levelArr[] = 0;
                    }
                    $articleData['level'] = json_encode($levelArr);
                }
            }
            var_dump($articleData['level'], '----------$articleData[level]----------1');
            if ($articleData['keyword'] == '') {
                //提取标题+内容中的关键词
                $articleData['keyword'] = $data['title'];
                //  . substr(str_replace(' ', '', strip_tags($data['content'])), 0, 20);
                Jieba::init(); // 初始化 jieba-php
                Finalseg::init();
                $segList = Jieba::cut($articleData['keyword']);
                $segList1 = array_slice($segList, 0, 8);
                $articleData['keyword'] = implode(',', $segList1);

            }
            if ($articleData['introduce'] == '') {
                //提取内容中的描述
                $articleData['introduce'] = substr(str_replace(' ', '', strip_tags($data['content'])), 0, 100);
            }

            $id = Article::insertGetId($articleData);
            $articleDataContent = [
                'article_id' => $id,
                'content' => $data['content'],
            ];
            ArticleData::insertGetId($articleDataContent);

            //处理投票
            if ($is_survey == 1) {
                //生成年月日时分秒+8位随机数
                $uuid = date('YmdHis') . rand(10000000, 99999999);
                var_dump($suvey_array, 'suvey_array________');
                $suveys_array = is_array($suvey_array) ? $suvey_array : json_decode($suvey_array);
                var_dump($suveys_array, '---------------------1');
                var_dump($suvey_array, '---------------------2');
                $suvey_data = [];
                foreach ($suveys_array as $key => $value) {
                    if ($value == '') {
                        continue;
                    }
                    if (is_array($value)) {
                        $suvey_data[] = [
                            'sur_id' => $uuid,
                            'art_id' => $id,
                            'website_id' => $website_id ?? 2,
                            'survey_name' => $survey_name,
                            'choice_name' => $value[1],
                            'is_other' => 1,
                            'other_id' => 0,
                            'results' => 0,

                        ];
                    } else {
                        $suvey_data[] = [
                            'sur_id' => $uuid,
                            'art_id' => $id,
                            'website_id' => $website_id ?? 2,
                            'survey_name' => $survey_name,
                            'choice_name' => $value,
                            'is_other' => 0,
                            'other_id' => 0,
                            'results' => 0,

                        ];
                    }
                    if (empty($suvey_data)) {
                        throw new \Exception("投票数据为空");
                    }

                }
                $result = ArticleSurvey::insert($suvey_data);
                if (!$result) {
                    throw new \Exception("投票失败,ArticleSurvey插入失败");
                }
                $result = Article::where('id', $id)->update(['survey_id' => $uuid, 'survey_name' => $survey_name, 'is_survey' => $is_survey]);
                if (!$result) {
                    throw new \Exception("投票失败,更新主表失败");
                }
            }

            Db::commit();
            return Result::success(['id' => $id]);
        } catch (\Throwable $ex) {
            Db::rollBack();
            var_dump($ex->getMessage());
            return Result::error("创建失败", 0);
        }
    }

    /**
     * @param array $data
     * @return array
     */
    public function delArticle(array $data): array
    {
        $result = Article::where($data)->delete();
        //survey投票删除
        articleSurvey::where(['art_id' => $data['id']])->delete();
        if (!$result) {
            return Result::error("删除失败");
        }
        return Result::success($result);
    }

    /**
     * @param array $data
     * @return array
     */
    public function updateArticle(array $data): array
    {
        var_dump($data, '----------12-----------1');
        Db::beginTransaction();
        unset($data['user_type']);
        // unset($data['web_site_id']);
        unset($data['nav_add_pool_id']);
        try {
            //处理投票
            $is_survey = isset($data['is_survey']) ? $data['is_survey'] : 0;
            $survey_name = isset($data['survey_name']) ? $data['survey_name'] : '';
            $suvey_array = isset($data['suvey_array']) ? $data['suvey_array'] : '';
            $website_id = isset($data['website_id']) ? $data['website_id'] : 2;
            unset($data['is_survey']);
            unset($data['survey_name']);
            unset($data['suvey_array']);
            unset($data['website_id']);
            $data['web_site_id'] = is_array($data['web_site_id']) ? json_encode($data['web_site_id']) : ($data['web_site_id']);
            if ($data['hits'] == '') {
                $data['hits'] = 0;
            }
            if ($data['is_original'] == '') {
                $data['is_original'] = 0;
            }
            if ($data['status'] == '') {
                $data['status'] = 0;
            }

            $data['cat_arr_id'] = is_array($data['cat_arr_id']) ? json_encode($data['cat_arr_id']) : '';
            $data['tag'] = is_array($data['tag']) ? json_encode($data['tag']) : '';
            $articleData = $data;
            unset($articleData['content']);
            unset($articleData['status_name']);
            unset($articleData['name']);
            unset($articleData['content']);
            unset($articleData['pid_arr']);
            unset($articleData['pid']);
            //自动处理缩略图、关键字、描述
            if ($articleData['imgurl'] == '') {
                //如果没有图，设置level=0
                $levelArr = json_decode($articleData['level'], true);
                var_dump($levelArr, '----------levelArr-----------1');
                //content中提取图片第一个图，正则提取
                $reg = '/<img.*?src=[\"|\']?(.*?)[\"|\']?\s.*?>/i';
                preg_match_all($reg, $data['content'], $matches);
                if (isset($matches[1][0])) {
                    $articleData['imgurl'] = $matches[1][0];
                    //如果有图，设置level=3
                    if (!in_array(3, $levelArr)) {$levelArr[] = 3;}
                    $articleData['level'] = json_encode($levelArr);
                } else {
                    if (!in_array(0, $levelArr)) {
                        $levelArr[] = 0;
                    }
                    $articleData['level'] = json_encode($levelArr);
                }
            }
            var_dump($articleData['level'], '----------$articleData[level]----------1');
            if ($articleData['keyword'] == '') {
                //提取标题+内容中的关键词
                $articleData['keyword'] = $data['title'];
                //  . substr(str_replace(' ', '', strip_tags($data['content'])), 0, 20);
                Jieba::init(); // 初始化 jieba-php
                Finalseg::init();
                $segList = Jieba::cut($articleData['keyword']);
                $segList1 = array_slice($segList, 0, 8);
                $articleData['keyword'] = implode(',', $segList1);
            }
            if ($articleData['introduce'] == '') {
                //提取内容中的描述
                $articleData['introduce'] = substr(str_replace(' ', '', strip_tags($data['content'])), 0, 100);
            }

            $id = Article::where(['id' => $data['id']])->update($articleData);
            $articleDataContent = [
                'content' => $data['content'],
            ];
            ArticleData::where(['article_id' => $data['id']])->update($articleDataContent);
            //处理投票
            $id = $data['id'];
            $surveydata = ArticleSurvey::where(['art_id' => $data['id']])->delete();
            var_dump($suvey_array, 'suvey_array________delete');

            //处理投票
            if ($is_survey == 1) {
                //生成年月日时分秒+8位随机数
                $uuid = date('YmdHis') . rand(10000000, 99999999);
                $suveys_array = is_array($suvey_array) ? $suvey_array : json_decode($suvey_array);
                var_dump($suveys_array, '---------------------1');
                var_dump($suvey_array, '---------------------2');
                $suvey_data = [];

                if (is_array($suveys_array)) {
                    foreach ($suveys_array as $key => $value) {
                        if ($value == '') {
                            continue;
                        }
                        if (is_array($value)) {
                            $suvey_data[] = [
                                'sur_id' => $uuid,
                                'art_id' => $id,
                                'website_id' => $website_id ?? 2,
                                'survey_name' => $survey_name,
                                'choice_name' => $value[1],
                                'is_other' => 1,
                                'other_id' => 0,
                                'results' => 0,

                            ];
                        } else {
                            $suvey_data[] = [
                                'sur_id' => $uuid,
                                'art_id' => $id,
                                'website_id' => $website_id ?? 2,
                                'survey_name' => $survey_name,
                                'choice_name' => $value,
                                'is_other' => 0,
                                'other_id' => 0,
                                'results' => 0,
                            ];
                        }
                        if (empty($suvey_data)) {
                            throw new \Exception("投票数据为空");
                        }

                    }
                }
                $result = ArticleSurvey::insert($suvey_data);
                if (!$result) {
                    throw new \Exception("投票失败");
                }
                $result = Article::where('id', $id)->update(['survey_id' => $uuid, 'survey_name' => $survey_name, 'is_survey' => $is_survey]);
                if (!$result) {
                    throw new \Exception("投票失败");
                }
            } else {
                $result = Article::where('id', $id)->update(['survey_id' => '', 'survey_name' => '', 'is_survey' => 0]);
            }
            Db::commit();
            return Result::success([]);
        } catch (\Throwable $ex) {
            Db::rollBack();
            var_dump($ex->getMessage());
            return Result::error("更新失败1" . $ex->getMessage(), 0);
        }
    }

    /**
     * 更新资讯状态
     * @param array $data
     * @return array
     */
    public function upArticleStatus(array $data): array
    {
        $result = Article::where(['id' => $data['id']])->update($data);
        if ($result) {
            return Result::success();
        } else {
            return Result::error("更新状态失败", 0);
        }
    }
    /**
     * @param array $data
     * @return array
     */
    public function getArticleInfo(array $data): array
    {
        $where = [
            'article.id' => $data['id'],
            // 'article.status' => 1,
        ];
        $result = Article::where($where)->leftJoin("article_data", "article.id", "article_data.article_id")->first();
        $articleSurvey = ArticleSurvey::where(['art_id' => $data['id']])->get();
        $info = $result;
        // var_dump($info, 'info');
        $info['survey_array'] = $articleSurvey;
        if ($result) {
            return Result::success($info);
        } else {
            return Result::error("查询失败", 0);
        }
    }
    /**
     *  获取新闻
     * @param array $data
     * @return array
     */
    public function getWebsiteArticlett(array $data): array
    {

        $category = WebsiteCategory::where('website_id', $data['website_id'])->pluck('category_id');
        $result = [];
        if ($category) {
            $placeid = isset($data['placeid']) && !empty($data['placeid']) ? $data['placeid'] - 1 : 0;
            $where = [
                'status' => 1,
            ];
            var_dump($data, 'data-----------------');

            //如果是4：最新资讯（数据库已不存在） 5：资讯推荐（数据库已不存在）；
            // 1：头条资讯；2：轮播图；6：热点资讯；（数据库）
            var_dump($where, 'where-----------------');

            $result = Article::where($where)
                ->whereIn("catid", $category)
                ->where(function ($query) use ($data) {
                    $query->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0")
                        ->orWhereNull("ignore_ids");
                })
            //$data['level'] == 4 || $data['level'] == 5 查询随机
                ->when($data['level'] == 5, function ($query) {
                    $query->inRandomOrder()
                    //updated_at最近三十天;
                        ->where('updated_at', '>', date("Y-m-d H:i:s", strtotime("-30 day")));
                })
                ->when($data['level'] == 4, function ($query) {
                    $query->orderBy("updated_at", "desc");
                })
                ->when(!empty($data['level']), function ($query) use ($data) {
                    if ($data['level'] != 4 && $data['level'] != 5) {
                        $query->whereRaw("JSON_CONTAINS(level, '" . intval($data['level']) . "') = 1")
                            ->orderBy("updated_at", "desc");
                    }
                })
                ->offset($placeid)
                ->limit($data['pageSize'])
                ->get();
            if (empty($result)) {
                return Result::error("暂无头条新闻", 0);
            }
            return Result::success($result);
        } else {
            return Result::error("本网站下暂无相关栏目", 0);
        }
    }
    /**
     * 获取模块新闻
     * @param array $data
     * @return array
     */

    public function getWebsiteModelArticles(array $data): array
    {
        $catid = $data['catid'];
        $category = WebsiteCategory::where('website_id', $data['website_id'])->where('category_id', $catid)->select('category_id')->get();
        $category = $category->toArray();
        if (!empty($category)) {
            $where = [
                'status' => 1,
                'catid' => $catid,
            ];
            $placeid = isset($data['placeid']) && !empty($data['placeid']) ? $data['placeid'] - 1 : 0;
            // 1：文字新闻；2：轮播图；3：图文；
            // 级别：0：未分类
            // 3：推荐图片
            if ($data['level'] == 1) {
                $data['level'] = 0;
            }
            $result = Article::where($where)
                ->where(function ($query) use ($data) {
                    $query->whereRaw("JSON_CONTAINS(level, '" . intval($data['level']) . "') = 1")
                        ->orWhereNull("level")
                        ->orWhereRaw("level = '[]'");
                })
                ->where(function ($query) use ($data) {
                    $query->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0")
                        ->orWhereNull("ignore_ids");
                })
                ->orderBy("updated_at", "desc")
                ->offset($placeid)
                ->limit($data['pagesize'])
                ->get();
            if (empty($result)) {
                return Result::error("此栏目暂无相关新闻", 0);
            }
        } else {
            return Result::error("此网站暂无此栏目", 0);

        }
        return Result::success($result);
    }

    /**
     *获取新闻列表
     * @param array $data
     * @return array
     */
    public function getWebsiteArticleList(array $data): array
    {
        $where[] = ['status', '=', 1];
        if (isset($data['keyword']) && !empty($data['keyword'])) {
            array_push($where, ['article.title', 'like', '%' . $data['keyword'] . '%']);
        }
        if (isset($data['catid']) && !empty($data['catid'])) {
            if (is_array($data['catid'])) {
                $category = WebsiteCategory::where('website_id', $data['website_id'])->whereIn('category_id', $data['catid'])->pluck('category_id');
                array_push($where, ['catid', 'in', $data['catid']]);
            } else {
                $category = WebsiteCategory::where('website_id', $data['website_id'])->where('category_id', $data['catid'])->pluck('category_id');
                array_push($where, ['catid', '=', $data['catid']]);
            }
            if (empty($category)) {
                return Result::error("此网站暂无此栏目", 0);
            }
        }
        // return Result::success($where);
        $rep = Article::where(function ($query) use ($where) {
            foreach ($where as $condition) {
                if ($condition[1] === 'in') {
                    $query->whereIn($condition[0], $condition[2]);
                } else {
                    $query->where($condition[0], $condition[1], $condition[2]);
                }
            }
        })
            ->where(function ($query) use ($data) {
                $query->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0")
                    ->orWhereNull("ignore_ids");
            })
            ->orderBy("updated_at", "desc")
            ->limit($data['pageSize'])
            ->offset(($data['page'] - 1) * $data['pageSize'])
            ->get();

        $count = Article::where(function ($query) use ($where) {
            foreach ($where as $condition) {
                if ($condition[1] === 'in') {
                    $query->whereIn($condition[0], $condition[2]);
                } else {
                    $query->where($condition[0], $condition[1], $condition[2]);
                }
            }
        })->count();

        $data = [
            'rows' => $rep->toArray(),
            'count' => $count,
        ];

        if (empty($rep)) {
            return Result::error("没有信息数据");
        }
        return Result::success($data);

    }
    /**
     * 前端-获取新闻详情
     * @param array $data
     * @return array
     */
    public function selectWebsiteArticleInfo(array $data): array
    {
        $where = [
            'article.id' => $data['id'],
            'article.status' => 1,
        ];
        $result = Article::where($where)->leftJoin("article_data", "article.id", "article_data.article_id")
            ->where(function ($query) use ($data) {
                $query->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0")
                    ->orWhereNull("ignore_ids");
            })
            ->first();
        if (empty($result)) {
            return Result::error("暂无此新闻！", 0);
        }
        $category = WebsiteCategory::leftJoin('website', 'website.id', '=', 'website_category.website_id')
            ->select('website_category.*', 'website.website_name', 'website.suffix')
            ->where('website_category.website_id', $data['website_id'])
            ->where(['website_category.category_id' => $result['catid']])
            ->first();
        if (empty($category)) {
            return Result::error("查询失败", 0);
        }
        $result['category_id'] = $category['category_id'];
        $result['cat_name'] = $category['alias'];
        $result['website_name'] = $category['website_name'] ?? "";
        $result['suffix'] = $category['suffix'] ?? "";
        return Result::success($result);
    }

    /**
     * 前端-获取网站调查问卷
     * @param array $data
     * @return array
     */
    public function getWebsiteSurvey(array $data): array
    {
        if (isset($data['website_id']) && !empty($data['website_id'])) {
            $website = Website::where('id', $data['website_id'])->first();
            if (empty($website)) {
                return Result::error("暂无此网站", 0);
            }
        }
        if (isset($data['art_id']) && !empty($data['art_id'])) {
            $article = Article::where('id', $data['art_id'])->where('status', 1)->first();
            if (empty($article)) {
                return Result::error("暂无此文章", 0);
            }
            // return Result::error($data,0);
            $where['art_id'] = $data['art_id'];
            // $query = ArticleSurvey::where('art_id',$data['art_id']);

        } else {
            $survey = Article::where(function ($query) {
                $query->whereRaw("JSON_CONTAINS(cat_arr_id, '28')")
                    ->orWhereRaw("JSON_CONTAINS(cat_arr_id, '\"28\"')");
            })
                ->where('status', 1)
                ->where('is_survey', 1)
                ->select('survey_id')
                ->orderBy('updated_at', 'desc')
                ->first();
            if (empty($survey)) {
                return Result::error("暂无调查问卷", 0);
            }
            $where['sur_id'] = $survey['survey_id'];
            // $query = ArticleSurvey::where('sur_id',$survey['sur_id']);
        }
        // return Result::success($where);
        $result = ArticleSurvey::where($where)
            ->where(function ($query) {
                $query->where('is_other', 0)
                    ->orWhere(function ($subQuery) {
                        $subQuery->where('is_other', 1)
                            ->where('other_id', 0);
                    });
            })
            ->leftJoin('article', 'article_survey.art_id', 'article.id')
            ->select('article_survey.*', 'article.survey_type')
            ->get()->all();
        if (empty($result)) {
            return Result::error("此文章暂无调查问卷", 0);
        }
        return Result::success($result);
    }
    /**
     * 前端-添加网站调查问卷选项
     * @param array $data
     * @return array
     */
    public function addWebsiteSurveyOption(array $data): array
    {
        if (isset($data['website_id']) && !empty($data['website_id'])) {
            $website = Website::where('id', $data['website_id'])->first();
            if (empty($website)) {
                return Result::error("暂无此网站", 0);
            }
            if (isset($data['sur_id']) && !empty($data['sur_id'])) {
                $survey = ArticleSurvey::where('sur_id', $data['sur_id'])->where('website_id', $data['website_id'])->where('is_other', 1)->where('other_id', 0)->first();
                if (empty($survey)) {
                    return Result::error("此调查问卷不可添加选项", 0);
                }
                if (isset($data['choice_name']) && !empty($data['choice_name'])) {
                    $choice = [
                        'art_id' => $survey['art_id'],
                        'website_id' => $data['website_id'],
                        'survey_name' => $survey['survey_name'],
                        'choice_name' => $data['choice_name'],
                        'sur_id' => $survey['sur_id'],
                        'is_other' => 1,
                        'other_id' => $survey['id'],

                    ];
                    $result = ArticleSurvey::insertGetId($choice);
                    if (empty($result)) {
                        return Result::error("添加失败", 0);
                    }
                    return Result::success($result);
                }
            }
            return Result::error("添加失败", 0);
        }
        return Result::error("添加失败", 0);

    }
    /**
     * 前端-调查问卷投票
     * @param array $data
     * @return array
     */
    public function addWebsiteSurveyVote(array $data): array
    {
        // return Result::success($data);
        if (isset($data['website_id']) && !empty($data['website_id'])) {
            $website = Website::where('id', $data['website_id'])->first();
            if (empty($website)) {
                return Result::error("暂无此网站", 0);

            }
            if (isset($data['sur_id']) && !empty($data['sur_id'])) {
                $is_survey = ArticleSurvey::where('sur_id', $data['sur_id'])->first();
                // return Result::success($survey);
                if (empty($is_survey)) {
                    return Result::error("此调查问卷不存在", 0);
                }
                // return Result::success($survey);
                // 调查问卷类型
                if (isset($data['choice_id']) && !empty($data['choice_id'])) {
                    //多选 若是json型则转化成数组类型
                    if (strpos($data['choice_id'], '[') === 0) {
                        $data['choice_id'] = json_decode($data['choice_id'], true);
                    } else {
                        // 单选  也转换成数组
                        $data['choice_id'] = [$data['choice_id']];
                    }
                    $data['choice_id'] = array_map('intval', $data['choice_id']);
                    $other = ArticleSurvey::whereIn('id', $data['choice_id'])
                        ->where('website_id', $data['website_id'])
                        ->where('is_other', 1)
                        ->where('other_id', 0)
                        ->first();
                    if (!empty($other)) {
                        return Result::error("请选择已有的选项！", 0);
                    }
                    $choice['other'] = ArticleSurvey::whereIn('id', $data['choice_id'])
                        ->where('website_id', $data['website_id'])
                        ->where('is_other', 1)
                        ->where('other_id', '!=', 0)
                        ->first();
                    // return Result::success($choice['other']);
                    $choice_id = $data['choice_id'];
                    if (!empty($choice['other'])) {
                        // array_push($data['choice_id'],$choice['other']['other_id']);
                        if (!empty($choice_id)) {
                            $key = array_search($choice['other']['id'], $choice_id);
                            if ($key !== false) {
                                unset($choice_id[$key]);
                                $choice_id = array_values($choice_id);
                            }
                            array_push($choice_id, $choice['other']['other_id']);
                        } else {
                            $choice_id[0] = $choice['other']['other_id'];
                        }
                        // return Result::success($data['choice_id']);
                    }
                    // return Result::success($data);
                    $choice = ArticleSurvey::whereIn('id', $data['choice_id'])
                        ->where('website_id', $data['website_id'])
                        ->increment('results', 1);
                    if (empty($choice)) {
                        return Result::error("请选择已有的选项！", 0);
                    }
                    $survey['data'] = ArticleSurvey::where('sur_id', $data['sur_id'])
                        ->where('website_id', $data['website_id'])
                        ->where('other_id', 0)
                        ->get();
                    $survey['choice'] = $choice_id;
                    return Result::success($survey);

                }
                return Result::error("参数必填！");
            }
            return Result::error("此调查问卷不存在", 0);
        }
        return Result::error("参数必填！");
    }
    /**
     * 后端-获取网站调查问卷列表
     * @param array $data
     * @return array
     */
    public function getSurveyList(array $data): array
    {
        $where = [];
        if (isset($data['survey_name']) && !empty($data['survey_name'])) {
            array_push($where, ['survey_name', 'like', '%' . $data['survey_name'] . '%']);
        }
        if (isset($data['survey_type']) && $data['survey_type'] != null) {
            array_push($where, ['survey_type', '=', $data['survey_type']]);
        }
        if (isset($data['is_survey']) && $data['is_survey'] != null) {
            array_push($where, ['is_survey', '=', $data['is_survey']]);
        }
        // return Result::success($where);

        if (!empty($where)) {
            $query = Article::where($where)->where(function ($q) {
                $q->whereNotNull('survey_name')->where('survey_name', '!=', '');
            });
        } else {
            $query = Article::where(function ($q) {
                $q->whereNotNull('survey_name')->where('survey_name', '!=', '');
            });
        }

        $count = $query->count();
        $survey = $query->orderByDesc('id')
            ->limit($data['pageSize'])
            ->offset(($data['page'] - 1) * $data['pageSize'])
            ->get();
        if (empty($survey->toArray())) {
            return Result::error("暂无调查问卷!", 0);
        }
        $result = [
            'rows' => $survey,
            'count' => $count,
        ];
        return Result::success($result);
    }
    /**
     * 后端-获取网站调查问卷详情
     * @param array $data
     * @return array
     */
    public function getSurveyInfo(array $data): array
    {
        if (isset($data['sur_id']) && !empty($data['sur_id'])) {
            $where = ['sur_id' => $data['sur_id']];
            $choose = ArticleSurvey::where($where)->where('is_other', 0)
                ->leftJoin('article', 'article_survey.art_id', 'article.id')
                ->select('article_survey.*', 'article.survey_type')
                ->get()->all();
            if (empty($choose)) {
                return Result::error("此调查问卷不存在", 0);
            }
            $resultsArray = array_column($choose, 'results');
            $total = array_sum($resultsArray);
            $other = ArticleSurvey::where($where)->where('is_other', 1)->where('other_id', 0)->first();
            $others = ArticleSurvey::where($where)->where('is_other', 1)->where('other_id', '!=', 0)->orderByDesc('created_at')->get()->all();
            // $total = 0;
            if (!empty($other)) {
                $total = $total + $other['results'];
                $other['choice_name'] = $other['choice_name'] . '(其他)';
                if (!empty($others)) {
                    $other['hasChildren'] = true;
                    // array_push($other,['hasChildren','=',true]);
                    $other['children'] = $others;
                    $other_choices = [$other->toArray()];
                    $mer_choice = array_merge($choose, $other_choices);
                    $value_choice = array_values($mer_choice);
                } else {
                    // return Result::error('1111');
                    $other_choices = [$other->toArray()];
                    $other_choices = array_merge($choose, $other_choices);
                    $value_choice = array_values($other_choices);
                    // return Result::success($result);
                }
            } else {
                $value_choice = $choose;
            }
            $result = [
                'choose' => $value_choice,
                'total' => $total,
            ];
        }
        return Result::success($result);
    }

    /**
     * 前端-搜索新闻列表
     * @param array $data
     * @return array
     */
    public function selectWebsiteArticle(array $data): array
    {
        $where = [];
        // 初始化查询构造器
        $category = WebsiteCategory::where('website_id', $data['website_id'])->pluck('category_id');
        $query = Article::where('status', 1)
            ->whereIn('catid', $category)
            ->where(function ($query) use ($data) {
                $query->where(function ($subQuery) use ($data) {
                    $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0");
                })->orWhereNull("ignore_ids");
            });
        // return Result::success($all_articles);
        // 检查是否存在 cityid 参数
        if (isset($data['cityid']) && !empty($data['cityid'])) {
            $query->whereRaw("JSON_CONTAINS(city_arr_id, '" . intval($data['cityid']) . "')");
        }
        // 检查是否存在 department_id 参数
        if (isset($data['department_id']) && !empty($data['department_id'])) {
            $query->whereRaw("JSON_CONTAINS(department_arr_id, '" . intval($data['department_id']) . "')");
        }
        // 检查是否存在 keyword 参数
        if (isset($data['keyword']) && !empty($data['keyword'])) {
            $query->where('title', 'like', '%' . $data['keyword'] . '%');
        }
        // 计算总数
        $count = $query->count();
        // 分页查询
        $articles = $query->orderBy("updated_at", "desc")
            ->limit($data['pageSize'])
            ->offset(($data['page'] - 1) * $data['pageSize'])
            ->get()->all();
        if (empty($articles)) {
            return Result::error("没有符合条件的资讯数据");
        }
        $data = [
            'rows' => $articles,
            'count' => $count,
        ];
        return Result::success($data);
    }

    /**
     * 验证导航名称是否重复
     * @return void
     */
    public function checkCategoryName(array $data): array
    {
        $result = Category::when($data, function ($query) use ($data) {
            if (isset($data['name']) && $data['name']) {
                $query->where("name", $data['name']);
            }
            if (isset($data['id']) && $data['id']) {
                $query->where("id", "!=", $data['id']);
            }
        })->first();
        if ($result) {
            return Result::error("已存在");
        } else {
            return Result::success();
        }
    }

    //20250226  产品列表

    public function getGoodList(array $data): array
    {
        $type_id = isset($data['type_id']) ? $data['type_id'] : '';
        unset($data['type_id']);
        $user_id = isset($data['user_id']) ? $data['user_id'] : '';
        $where = [];
        if ($type_id != '10000') {
            $where = [
                'good.user_id' => $user_id,
            ];
        }
        //类型
        if (isset($data['type_id']) && $data['type_id']) {
            $where = [
                'type_id' => $data['type_id'],
            ];
        }
        //名称
        if (isset($data['name']) && $data['name']) {
            $where = [
                'good.name' => $data['name'],
            ];
        }
        $where1 = [];
        //website_id
        // if (isset($data['website_id']) && $data['website_id']) {
        //     $where1 = [
        //         'good.website_id', 'like', '%' . $data['website_id'] . '%',
        //     ];
        // }
        // website_name
        if (isset($data['website_name']) && $data['website_name']) {
            $where1[] = ['website.website_name', 'like', '%' . $data['website_name'] . '%'];
        }

        // catid
        if (isset($data['category_name']) && $data['category_name']) {
            $where1[] = ['category.name', 'like', '%' . $data['category_name'] . '%'];
        }

        // $result = Good::where($where)
        // ->orderBy("updated_at", "desc")->paginate($data['pige_size'], ['*'], 'page', $data['page']);
        $result = Good::where($where)
            ->when(!empty($where1), function ($query) use ($where1) {
                return $query->where($where1);
            })
            ->leftJoin('district', 'good.city_id', '=', 'district.id')
            ->leftJoin('website', 'good.website_id', '=', 'website.id')
            ->leftJoin('category', 'good.catid', '=', 'category.id')
            ->select('good.*', 'district.name as cityname', 'website.website_name as website_name', 'category.name as category_name')
            ->orderBy("id", "desc")
            ->limit($data['page_size'])
            ->offset(($data['page'] - 1) * $data['page_size'])
            ->get();
        $count = Good::where($where)
            ->leftJoin('district', 'good.city_id', '=', 'district.id')
            ->leftJoin('website', 'good.website_id', '=', 'website.id')
            ->leftJoin('category', 'good.catid', '=', 'category.id')
            ->select('good.*', 'district.name as cityname', 'website.website_name as website_name', 'category.name as category_name')
            ->orderBy("updated_at", "desc")->count();
        $data = [
            'rows' => $result->toArray(),
            'count' => $count,
        ];

        if (empty($result)) {
            return Result::error("此栏目暂无相关产品", 0);
        }
        return Result::success($data);
    }
    public function getGoodInfo(array $data): array
    {
        $result = Good::where('id', $data['id'])->first();
        if (empty($result)) {
            return Result::error("此产品不存在", 0);
        }
        return Result::success($result);
    }
    public function addGood(array $data): array
    {
        // unset($data['city_arr_id']);
        // unset($data['cat_arr_id']);
        $data['city_id'] = end($data['city_arr_id']);
        $data['catid'] = end($data['cat_arr_id']);
        $data['city_arr_id'] = isset($data['city_arr_id']) ? json_encode($data['city_arr_id']) : '';
        $data['cat_arr_id'] = isset($data['cat_arr_id']) ? json_encode($data['cat_arr_id']) : '';
        $data['imgurl'] = isset($data['imgurl']) ? json_encode($data['imgurl']) : '';
        unset($data['imgUrl']);
        $result = Good::insert($data);
        if (empty($result)) {
            return Result::error("添加失败", 0);
        }
        return Result::success($result);
    }
    public function updateGood(array $data): array
    {
        $data['city_id'] = end($data['city_arr_id']);
        $data['catid'] = end($data['cat_arr_id']);
        $data['city_arr_id'] = isset($data['city_arr_id']) ? json_encode($data['city_arr_id']) : '';
        $data['cat_arr_id'] = isset($data['cat_arr_id']) ? json_encode($data['cat_arr_id']) : '';
        $data['imgurl'] = isset($data['imgurl']) ? json_encode($data['imgurl']) : '';
        //设置东八区
        date_default_timezone_set('Asia/Shanghai');
        $data['updated_at'] = date('Y-m-d H:i:s');
        $result = Good::where('id', $data['id'])->update($data);
        if (empty($result)) {
            return Result::error("更新失败", 0);
        }
        return Result::success($result);
    }
    public function delGood(array $data): array
    {
        $result = Good::where('id', $data['id'])->delete();
        if (empty($result)) {
            return Result::error("删除失败", 0);
        }
        return Result::success($result);
    }

    //20250226  产品列表
    //20250306  求职信息
    public function getJobHuntingList(array $data): array
    {
        $where = [];
        if (isset($data['username']) && !empty($data['username'])) {

            $where[] = ['user.user_name', 'like', '%' . $data['username'] . '%'];
        }
        $type_id = isset($data['type_id']) ? $data['type_id'] : '';
        $user_id = isset($data['user_id']) ? $data['user_id'] : '';
        unset($data['type_id']);
        if ($type_id != '10000') {
            $where[] = ['job_hunting.user_id', '=', $user_id];
        }
        $result = JobHunting::where($where)
            ->leftJoin('user', 'user.id', '=', 'job_hunting.user_id')
            ->leftJoin('website', 'website.id', '=', 'job_hunting.website_id')
            ->select('job_hunting.*', 'user.nickname as nickname', 'user.user_name as username', 'website.website_name as website_name')
            ->orderBy("id", "desc")
            ->limit($data['page_size'])
            ->offset(($data['page'] - 1) * $data['page_size'])
            ->get();
        if (empty($result)) {
            return Result::error("查询失败", 0);
        }
        $count = JobHunting::where($where)
            ->leftJoin('user', 'user.id', '=', 'job_hunting.user_id')
            ->leftJoin('website', 'website.id', '=', 'job_hunting.website_id')
            ->count();
        $data = [
            'rows' => $result->toArray(),
            'count' => $count,
        ];
        return Result::success($data);
    }
    public function addJobHunting(array $data): array
    {
        date_default_timezone_set('Asia/Shanghai');
        unset($data['company_name']);
        unset($data['job_industry']);
        unset($data['job_name']);
        unset($data['department']);
        unset($data['job_timeList']);
        unset($data['job_content']);
        $data['created_at'] = date('Y-m-d H:i:s');
        $data['updated_at'] = date('Y-m-d H:i:s');
        var_dump($data, '-----------------test---------');
        $result = JobHunting::create($data);
        if (empty($result)) {
            return Result::error("添加失败", 0);
        }
        return Result::success($result);
    }
    public function delJobHunting(array $data): array
    {
        $result = JobHunting::where('id', $data['id'])->delete();
        if (empty($result)) {
            return Result::error("删除失败", 0);
        }
        return Result::success($result);
    }
    public function updateJobHunting(array $data): array
    {
        //设置东八区
        date_default_timezone_set('Asia/Shanghai');
        unset($data['company_name']);
        unset($data['job_industry']);
        unset($data['job_name']);
        unset($data['department']);
        unset($data['job_timeList']);
        unset($data['job_content']);
        $data['created_at'] = date('Y-m-d H:i:s');
        $data['updated_at'] = date('Y-m-d H:i:s');
        $result = JobHunting::where('id', $data['id'])->update($data);
        if (empty($result)) {
            return Result::error("更新失败", 0);
        }
        return Result::success($result);
    }
    public function getJobHuntingInfo(array $data): array
    {
        $result = JobHunting::where('id', $data['id'])->first();
        if (empty($result)) {
            return Result::error("查询失败", 0);
        }
        return Result::success($result);
    }
    public function getJobHuntingData(array $data): array
    {
        $jobEnum = JobEnum::get();
        $jobIndustry = JobIndustry::get();
        $jobNature = JobNature::get();
        $jobPosition = JobPosition::get();
        $data = [
            'jobEnum' => $jobEnum,
            'jobIndustry' => $jobIndustry,
            'jobNature' => $jobNature,
            'jobPosition' => $jobPosition,
        ];
        return Result::success($data);
    }
    public function delJobHuntingInfo(array $data): array
    {
        $result = JobHunting::where('id', $data['id'])->delete();
        return Result::success();
    }
}
